@@ -19,7 +19,6 @@ from webob import exc
 
 from murano.api.v1 import request_statistics
 from murano.common.helpers import token_sanitizer
-from murano.common.i18n import _LE
 from murano.common import policy
 from murano.common import utils
 from murano.common import wsgi
@@ -51,7 +50,7 @@ class Controller(object):
         if all_environments:
             query = unit.query(models.Environment) \
                 .options(load_only('tenant_id')) \
-                .filter_by(tenant_id=request.context.tenant) \
+                .filter_by(tenant_id=request.context.project_id) \
                 .join(models.Task) \
                 .order_by(desc(models.Task.created))
             result = query.all()
@@ -111,13 +110,13 @@ def _patch_description(description):
 def verify_and_get_deployment(db_session, environment_id, deployment_id):
     deployment = db_session.query(models.Task).get(deployment_id)
     if not deployment:
-        LOG.error(_LE('Deployment with id {id} not found')
+        LOG.error('Deployment with id {id} not found'
                   .format(id=deployment_id))
         raise exc.HTTPNotFound
     if deployment.environment_id != environment_id:
-        LOG.error(_LE('Deployment with id {d_id} not found in environment '
-                      '{env_id}').format(d_id=deployment_id,
-                                         env_id=environment_id))
+        LOG.error('Deployment with id {d_id} not found in environment '
+                  '{env_id}'.format(d_id=deployment_id,
+                                    env_id=environment_id))
         raise exc.HTTPBadRequest
 
     deployment.description = _patch_description(deployment.description)
