@@ -15,19 +15,37 @@
 import contextlib
 import os
 import shutil
-import string
 import sys
 import tempfile
 import zipfile
 
-import semantic_version
 import yaml
 
+from murano.common.helpers import path
+from murano.common.plugins import package_types_loader
+from murano.common import utils
 import murano.packages.exceptions as e
 import murano.packages.hot_package
 import murano.packages.mpl_package
 
 
+PLUGIN_LOADER = None
+
+
+def get_plugin_loader():
+    global PLUGIN_LOADER
+
+    if PLUGIN_LOADER is None:
+        PLUGIN_LOADER = package_types_loader.PluginLoader()
+        for runtime_version in ('1.0', '1.1', '1.2', '1.3', '1.4'):
+            format_string = 'MuranoPL/' + runtime_version
+            PLUGIN_LOADER.register_format(
+                format_string, murano.packages.mpl_package.MuranoPlPackage)
+        PLUGIN_LOADER.register_format(
+            'Heat.HOT/1.0', murano.packages.hot_package.HotPackage)
+    return PLUGIN_LOADER
+
+
 @contextlib.contextmanager
 def load_from_file(archive_path, target_dir=None, drop_dir=False):
     if not os.path.isfile(archive_path):
@@ -37,7 +55,7 @@ def load_from_file(archive_path, target_dir=None, drop_dir=False):
         target_dir = tempfile.mkdtemp()
         created = True
     elif not os.path.exists(target_dir):
-        os.mkdir(target_dir)
+        os.makedirs(target_dir)
         created = True
     else:
         if os.listdir(target_dir):
@@ -59,23 +77,14 @@ def load_from_file(archive_path, target_dir=None, drop_dir=False):
                 shutil.rmtree(target_dir)
             else:
                 for f in os.listdir(target_dir):
-                    os.unlink(os.path.join(target_dir, f))
+                    os.unlink(path.secure_join(target_dir, f))
 
 
 def load_from_dir(source_directory, filename='manifest.yaml'):
-    formats = {
-        'MuranoPL': {
-            ('1.0.0', '1.2.0'): murano.packages.mpl_package.MuranoPlPackage,
-        },
-        'Heat.HOT': {
-            ('1.0.0', '1.0.0'): murano.packages.hot_package.HotPackage
-        }
-    }
-
     if not os.path.isdir(source_directory) or not os.path.exists(
             source_directory):
         raise e.PackageLoadError('Invalid package directory')
-    full_path = os.path.join(source_directory, filename)
+    full_path = path.secure_join(source_directory, filename)
     if not os.path.isfile(full_path):
         raise e.PackageLoadError('Unable to find package manifest')
 
@@ -84,24 +93,17 @@ def load_from_dir(source_directory, filename='manifest.yaml'):
             content = yaml.safe_load(stream)
     except Exception as ex:
         trace = sys.exc_info()[2]
-        raise e.PackageLoadError(
-            "Unable to load due to '{0}'".format(str(ex))), None, trace
-    if content:
-        p_format_spec = str(content.get('Format') or 'MuranoPL/1.0')
-        if p_format_spec[0] in string.digits:
-            p_format_spec = 'MuranoPL/' + p_format_spec
-        parts = p_format_spec.split('/', 1)
-        if parts[0] not in formats:
+        utils.reraise(
+            e.PackageLoadError,
+            e.PackageLoadError("Unable to load due to '{0}'".format(ex)),
+            trace)
+    else:
+        format_spec = str(content.get('Format') or 'MuranoPL/1.0')
+        if format_spec[0].isdigit():
+            format_spec = 'MuranoPL/' + format_spec
+        plugin_loader = get_plugin_loader()
+        handler = plugin_loader.get_package_handler(format_spec)
+        if handler is None:
             raise e.PackageFormatError(
-                'Unknown or missing format version')
-        format_set = formats[parts[0]]
-        version = semantic_version.Version('0.0.0')
-        if len(parts) > 1:
-            version = semantic_version.Version.coerce(parts[1])
-        for key, value in format_set.iteritems():
-            min_version = semantic_version.Version(key[0])
-            max_version = semantic_version.Version(key[1])
-            if min_version <= version <= max_version:
-                return value(source_directory, content, parts[0], version)
-        raise e.PackageFormatError(
-            'Unsupported {0} format version {1}'.format(parts[0], version))
+                'Unsupported format {0}'.format(format_spec))
+        return handler(source_directory, content)
