@@ -13,7 +13,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
+from unittest import mock
+
 from oslo_config import cfg
 
 try:
@@ -22,7 +23,6 @@ except ImportError:
     from io import StringIO
 
 from murano.cmd import manage
-from murano.common.i18n import _LE
 from murano.db.catalog import api as db_catalog_api
 from murano.db import models
 from murano.db import session as db_session
@@ -146,8 +146,8 @@ class TestManage(test_base.MuranoWithDBTestCase):
         manage.do_import_package()
 
         mock_log.error.assert_called_once_with(
-            _LE("Package '{name}' exists ({pkg_id}). Use --update.")
-            .format(name='test_full_name', pkg_id=self.test_package.id))
+            "Package '{name}' exists ({pkg_id}). Use --update."
+                .format(name='test_full_name', pkg_id=self.test_package.id))
 
     @mock.patch('sys.stdout', new_callable=StringIO)
     def test_do_list_categories(self, mock_stdout):
@@ -218,14 +218,14 @@ class TestManage(test_base.MuranoWithDBTestCase):
     def test_main_except_runtime_error(self, mock_conf):
         mock_conf.side_effect = RuntimeError
 
-        with self.assertRaisesRegexp(SystemExit, 'ERROR:'):
+        with self.assertRaisesRegex(SystemExit, 'ERROR:'):
             manage.main()
 
     @mock.patch('murano.cmd.manage.CONF')
     def test_main_except_general_exception(self, mock_conf):
         mock_conf.command.func.side_effect = Exception
 
-        expected_err_msg = _LE("murano-manage command failed:")
+        expected_err_msg = "murano-manage command failed:"
 
-        with self.assertRaisesRegexp(SystemExit, expected_err_msg):
+        with self.assertRaisesRegex(SystemExit, expected_err_msg):
             manage.main()
